@@ -5,8 +5,8 @@ use strict;
 use warnings;
 
 BEGIN {
-    our $VERSION = "0.16";
-    our @EXPORT_OK = qw/parse_urlencoded parse_urlencoded build_urlencoded build_urlencoded_utf8/;
+    our $VERSION = "0.17";
+    our @EXPORT_OK = qw/parse_urlencoded parse_urlencoded_arrayref build_urlencoded build_urlencoded_utf8/;
 
     my $use_pp = $ENV{WWW_FORM_URLENCODED_PP};
 
